{% extends "base.html" %}
{% load url from future %}
{% load i18n %}

{% block main %}
<h2>{% trans "Password reset successful" %}</h2>
<p>{% trans "We have sent you instructions for setting your password." %}</p>
{% endblock %}
